#
# spec file for package xgboost
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global scala_short_version 2.13
%global scala_version %{scala_short_version}.12
%global groupId ml.dmlc
%global artifactId xgboost4j
Name:           xgboost
Version:        2.0.0
Release:        1.2
Summary:        Gradient Boosting (GBDT, GBRT or GBM) Library
License:        Apache-2.0
URL:            https://github.com/dmlc/%{name}
Source0:        %{name}-%{version}.tar.xz
Source1:        %{artifactId}-build.xml
Patch0:         xgboost-fix-big-endian.patch
Patch1:         no-hadoop.patch
Patch2:         xgboost-2.0.0-python34.patch
Patch3:         xgboost-2.0.0-cmake.patch
BuildRequires:  akka
BuildRequires:  ant
BuildRequires:  apache-commons-logging
BuildRequires:  cmake >= 3.5
BuildRequires:  fdupes
BuildRequires:  javapackages-local
BuildRequires:  kryo
BuildRequires:  objenesis
BuildRequires:  python3
BuildRequires:  scala
BuildRequires:  scala-ant
BuildRequires:  typesafe-config
BuildRequires:  xmvn-install
BuildRequires:  xmvn-resolve
%if 0%{?suse_version} <= 1500
BuildRequires:  gcc8-c++ >= 8.1
%else
BuildRequires:  gcc-c++
%endif

%description
Scalable, Portable and Distributed Gradient Boosting (GBDT, GBRT or
GBM) Library, for Python, R, Java, Scala, C++ and more. Runs on
single machine, Hadoop, Spark, Flink and DataFlow

%package javadoc
Summary:        Javadoc for %{name}
BuildArch:      noarch

%description javadoc
%{summary}

%prep
%setup -q
cp %{SOURCE1} jvm-packages/%{artifactId}/build.xml
%ifarch s390x ppc64
%patch0
%endif
%patch1 -p1
%patch2 -p1
%patch3 -p1
%pom_xpath_set pom:project/pom:properties/pom:scala.version %{scala_version} jvm-packages
%pom_xpath_set pom:project/pom:properties/pom:scala.binary.version %{scala_short_version} jvm-packages
%pom_remove_dep ":scala-collection-compat_\${scala.binary.version}" jvm-packages/%{artifactId}

%{mvn_alias} :{*}_{*} :@1
%{mvn_package} :xgboost-jvm __noinstall

%build
pushd jvm-packages
%if 0%{?suse_version} <= 1500
export CC=gcc-8
export CXX=g++-8
%endif
%ifarch x86_64 aarch64
python3 create_jni.py
%endif
popd
pushd jvm-packages/%{artifactId}
mkdir -p lib
build-jar-repository -s lib akka kryo commons-logging scala typesafe-config objenesis/objenesis
%{ant} jar javadoc
popd

%install
install -dm 0755 %{buildroot}%{_jnidir}/%{name}
install -pm 0644 jvm-packages/%{artifactId}/target/%{artifactId}-%{version}.jar %{buildroot}%{_jnidir}/%{name}/%{artifactId}_%{scala_short_version}.jar

install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
%{mvn_install_pom} jvm-packages/%{artifactId}/pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{artifactId}_%{scala_short_version}.pom
%add_maven_depmap %{name}/%{artifactId}_%{scala_short_version}.pom %{name}/%{artifactId}_%{scala_short_version}.jar -a %{groupId}:%{artifactId}

install -dm 0755 %{buildroot}%{_javadocdir}
cp -r jvm-packages/%{artifactId}/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE

%changelog
* Thu Oct 12 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 2.0.0
  * Changes:
    + Stop using Rabit in prediction (#9054)
    + Set feature_names and feature_types in jvm-packages.
    This is to prepare support for categorical features (#9364)
    + Scala 2.13 support. (#9099)
    + Change training stage from ResultStage to ShuffleMapStage
    (#9423)
    + Automatically set the max/min direction for the best score
    during early stopping. (#9404)
    + Revised support for flink (#9046)
  * Breaking changes:
    + Scala-based tracker is removed. (#9078, #9045)
    + Change DeviceQuantileDmatrix into QuantileDMatrix (#8461)
- Added patches:
  * no-hadoop.patch
    + revert commit bringing in apache-hadoop dependency, since
    we don't have that one
  * xgboost-2.0.0-cmake.patch
    + allow building with cmake versions we have in SLE-15 and
    SLE-12-SP5
  * xgboost-2.0.0-python34.patch
    + allow running scripts with python 3.4 by removing the f""
    that is 3.6+ feature
* Mon Oct  2 2023 Fridrich Strba <fstrba@suse.com>
- Build using ant to avoid dependency on scala-maven-plugin
- Build with source/target 8 so that it eventually can be built
  using OpenJDK 21
- Removed patch:
  * use-python3.patch
    + not needed any more since we call the python3 from spec file
* Mon Nov 28 2022 Steve Kowalik <steven.kowalik@suse.com>
- Add patch use-python3.patch:
  * Use python3 during the build.
- Change BuildRequires to python3.
* Mon Apr 27 2020 Fridrich Strba <fstrba@suse.com>
- Pull sources with source service in order to have the right
  revisions of submodules
- Added patch:
  * xgboost-fix-big-endian.patch
    + flip default from little endian to big endian on big endian
    architectures
* Fri Mar  6 2020 Fridrich Strba <fstrba@suse.com>
- Initial packaging of xgboost 0.90
